@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2013 jeanfi@gmail.com
+ * Copyright (C) 2010-2014 jeanfi@gmail.com
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -16,6 +16,9 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  * 02110-1301 USA
  */
+#define _LARGEFILE_SOURCE 1
+#include "config.h"
+
 #include <locale.h>
 #include <libintl.h>
 #define _(str) gettext(str)
@@ -34,7 +37,7 @@
 
 #include "pio.h"
 #include "hdd.h"
-#include "log.h"
+#include <plog.h>
 
 static int filter_sd(const char *p)
 {
@@ -51,7 +54,7 @@ create_sensor(char *id, char *name, SkDisk *disk, int values_max_length)
 
 	s = psensor_create(id,
 			   strdup(name),
-			   strdup("HDD"),
+			   strdup(_("Disk")),
 			   t,
 			   values_max_length);
 
