@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2013 jeanfi@gmail.com
+ * Copyright (C) 2010-2014 jeanfi@gmail.com
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -119,7 +119,7 @@ create_sensor(char *id, char *name, int values_max_length)
 
 	t = SENSOR_TYPE_HDD | SENSOR_TYPE_HDDTEMP | SENSOR_TYPE_TEMP;
 
-	return psensor_create(id, name, strdup("HDD"),
+	return psensor_create(id, name, strdup(_("Disk")),
 			      t,
 			      values_max_length);
 }
