@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2013 jeanfi@gmail.com
+ * Copyright (C) 2010-2014 jeanfi@gmail.com
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -37,6 +37,7 @@
 #include "ui_sensorlist.h"
 #include "ui_color.h"
 #include "lmsensor.h"
+#include "notify_cmd.h"
 #include "slog.h"
 #include "ui_pref.h"
 #include "ui_graph.h"
@@ -76,10 +77,10 @@ static void print_version()
 	printf(_("Copyright (C) %s jeanfi@gmail.com\n"
 		 "License GPLv2: GNU GPL version 2 or later "
 		 "<http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>\n"
-		 "This is free software: you are free to change and "
+		 "This is free software: you are free to change and"
 		 " redistribute it.\n"
 		 "There is NO WARRANTY, to the extent permitted by law.\n"),
-	       "2010-2013");
+	       "2010-2014");
 }
 
 static void print_help()
@@ -218,7 +219,7 @@ gboolean ui_refresh_thread(gpointer data)
 #ifdef HAVE_UNITY
 	ui_unity_launcher_entry_update(ui->sensors,
 				       !cfg->unity_launcher_count_disabled,
-				       cfg->temperature_unit == CELCIUS);
+				       cfg->temperature_unit == CELSIUS);
 #endif
 
 	if (ui->graph_update_interval != cfg->graph_update_interval) {
@@ -241,6 +242,8 @@ static void cb_alarm_raised(struct psensor *sensor, void *data)
 	if (sensor->alarm_enabled)
 		ui_notify(sensor, (struct ui_psensor *)data);
 #endif
+
+	notify_cmd(sensor);
 }
 
 static void associate_colors(struct psensor **sensors)
@@ -263,7 +266,7 @@ static void associate_colors(struct psensor **sensors)
 	int i;
 	struct color c;
 
-	for (cur = sensors, i = 0; *cur; cur++) {
+	for (cur = sensors, i = 0; *cur; cur++, i++) {
 		color_set(&c,
 			  colors[i % COLORS_COUNT][0],
 			  colors[i % COLORS_COUNT][1],
