@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2013 jeanfi@gmail.com
+ * Copyright (C) 2010-2014 jeanfi@gmail.com
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -23,6 +23,7 @@
 #include "cfg.h"
 #include "ui_pref.h"
 #include "ui_color.h"
+#include <pxdg.h>
 
 GdkColor *color_to_gdkcolor(struct color *color)
 {
@@ -51,8 +52,10 @@ void ui_pref_dialog_run(struct ui_psensor *ui)
 	GtkComboBox *w_sensorlist_pos;
 	GtkToggleButton *w_hide_window_decoration, *w_keep_window_below,
 		*w_enable_menu, *w_enable_launcher_counter, *w_hide_on_startup,
-		*w_win_restore, *w_slog_enabled;
+		*w_win_restore, *w_slog_enabled, *w_autostart;
 	GtkComboBoxText *w_temp_unit;
+	GtkEntry *w_notif_script;
+	char *notif_script;
 
 	cfg = ui->config;
 
@@ -71,6 +74,14 @@ void ui_pref_dialog_run(struct ui_psensor *ui)
 
 	diag = GTK_DIALOG(gtk_builder_get_object(builder, "dialog1"));
 
+	w_notif_script = GTK_ENTRY(gtk_builder_get_object(builder,
+							  "notif_script"));
+	notif_script = config_get_notif_script();
+	if (notif_script) {
+		gtk_entry_set_text(GTK_ENTRY(w_notif_script), notif_script);
+		free(notif_script);
+	}
+
 	color_fg = color_to_gdkcolor(cfg->graph_fgcolor);
 	w_color_fg = GTK_COLOR_BUTTON(gtk_builder_get_object(builder,
 							     "color_fg"));
@@ -116,6 +127,10 @@ void ui_pref_dialog_run(struct ui_psensor *ui)
 	gtk_toggle_button_set_active(w_keep_window_below,
 				     cfg->window_keep_below_enabled);
 
+	w_autostart = GTK_TOGGLE_BUTTON
+		(gtk_builder_get_object(builder, "autostart"));
+	gtk_toggle_button_set_active(w_autostart, pxdg_is_autostarted());
+
 	w_enable_menu = GTK_TOGGLE_BUTTON
 		(gtk_builder_get_object(builder, "enable_menu"));
 	gtk_toggle_button_set_active(w_enable_menu, !cfg->menu_bar_disabled);
@@ -158,6 +173,9 @@ void ui_pref_dialog_run(struct ui_psensor *ui)
 
 		pthread_mutex_lock(&ui->sensors_mutex);
 
+		config_set_notif_script
+			(gtk_entry_get_text(GTK_ENTRY(w_notif_script)));
+
 		gtk_color_button_get_color(w_color_fg, &color);
 		color_set(cfg->graph_fgcolor,
 			  color.red, color.green, color.blue);
@@ -227,6 +245,8 @@ void ui_pref_dialog_run(struct ui_psensor *ui)
 
 		config_save(cfg);
 
+		pxdg_set_autostart(gtk_toggle_button_get_active(w_autostart));
+
 		pthread_mutex_unlock(&ui->sensors_mutex);
 
 		ui_window_update(ui);
